@@ -1,10 +1,10 @@
 #---------------------------------------------------------------------
-# $Id: DNS.pm 1840 2007-07-07 22:03:44Z cjm $
+# $Id: DNS.pm 1989 2008-04-25 23:51:04Z cjm $
 package WebService::NFSN::DNS;
 #
 # Copyright 2007 Christopher J. Madsen
 #
-# Author: Christopher J. Madsen <cjm@pobox.com>
+# Author: Christopher J. Madsen <perl@cjmweb.net>
 # Created:  3 Apr 2007
 #
 # This program is free software; you can redistribute it and/or modify
@@ -20,14 +20,14 @@ package WebService::NFSN::DNS;
 
 use 5.006;
 use strict;
-use JSON::XS 'from_json';
+use warnings;
 
 use base 'WebService::NFSN::Object';
 
 #=====================================================================
 # Package Global Variables:
 
-our $VERSION = '0.02';  # Also update VERSION section in documentation
+our $VERSION = '0.05';
 
 #=====================================================================
 BEGIN {
@@ -57,7 +57,7 @@ WebService::NFSN::DNS - Access NFSN DNS information
 
 =head1 VERSION
 
-This document describes WebService::NFSN::DNS version 0.02
+This document describes version 0.05 of WebService::NFSN::DNS, released April 25, 2008 as part of WebService-NFSN version 0.05.
 
 
 =head1 SYNOPSIS
