@@ -1,10 +1,10 @@
 #---------------------------------------------------------------------
-# $Id: Email.pm 1938 2007-12-20 05:57:26Z cjm $
+# $Id: Email.pm 1989 2008-04-25 23:51:04Z cjm $
 package WebService::NFSN::Email;
 #
 # Copyright 2007 Christopher J. Madsen
 #
-# Author: Christopher J. Madsen <cjm@pobox.com>
+# Author: Christopher J. Madsen <perl@cjmweb.net>
 # Created:  3 Apr 2007
 #
 # This program is free software; you can redistribute it and/or modify
@@ -20,14 +20,14 @@ package WebService::NFSN::Email;
 
 use 5.006;
 use strict;
-use JSON::XS 'from_json';
+use warnings;
 
 use base 'WebService::NFSN::Object';
 
 #=====================================================================
 # Package Global Variables:
 
-our $VERSION = '0.04';  # Also update VERSION section in documentation
+our $VERSION = '0.05';
 
 #=====================================================================
 BEGIN {
@@ -54,7 +54,7 @@ WebService::NFSN::Email - Access NFSN email forwarding
 
 =head1 VERSION
 
-This document describes WebService::NFSN::Email version 0.04
+This document describes version 0.05 of WebService::NFSN::Email, released April 25, 2008 as part of WebService-NFSN version 0.05.
 
 
 =head1 SYNOPSIS
