@@ -1,10 +1,10 @@
 #---------------------------------------------------------------------
-# $Id: Member.pm 1860 2007-08-09 05:03:08Z cjm $
+# $Id: Member.pm 1989 2008-04-25 23:51:04Z cjm $
 package WebService::NFSN::Member;
 #
 # Copyright 2007 Christopher J. Madsen
 #
-# Author: Christopher J. Madsen <cjm@pobox.com>
+# Author: Christopher J. Madsen <perl@cjmweb.net>
 # Created:  3 Apr 2007
 #
 # This program is free software; you can redistribute it and/or modify
@@ -20,14 +20,14 @@ package WebService::NFSN::Member;
 
 use 5.006;
 use strict;
-use JSON::XS 'from_json';
+use warnings;
 
 use base 'WebService::NFSN::Object';
 
 #=====================================================================
 # Package Global Variables:
 
-our $VERSION = '0.03';  # Also update VERSION section in documentation
+our $VERSION = '0.05';
 
 #=====================================================================
 BEGIN {
@@ -50,7 +50,7 @@ WebService::NFSN::Member - Access NFSN member API
 
 =head1 VERSION
 
-This document describes WebService::NFSN::Member version 0.03
+This document describes version 0.05 of WebService::NFSN::Member, released April 25, 2008 as part of WebService-NFSN version 0.05.
 
 
 =head1 SYNOPSIS
